@@ -5,12 +5,39 @@
 #  SPDX-License-Identifier: BSD-3-Clause
 #
 import sys
+from . import v1, v2
+from firecrest.Authorization import ClientCredentialsAuth
+from firecrest.FirecrestException import (
+    ClientsCredentialsException,
+    FirecrestException,
+    HeaderException,
+    NotImplementedOnAPIversion,
+    StorageDownloadException,
+    StorageUploadException,
+    UnauthorizedException,
+    UnexpectedStatusException,
+)
 
-
-__version__ = "2.2.0"
+__version__ = "3.4.0"
 __app_name__ = "firecrest"
 MIN_PYTHON_VERSION = (3, 7, 0)
 
+__all__ = [
+    "v1",
+    "v2",
+    "ClientCredentialsAuth",
+    "ClientsCredentialsException",
+    "FirecrestException",
+    "HeaderException",
+    "NotImplementedOnAPIversion",
+    "StorageDownloadException",
+    "StorageUploadException",
+    "UnauthorizedException",
+    "UnexpectedStatusException",
+    "__version__",
+    "__app_name__",
+]
+
 # Check python version
 if sys.version_info[:3] < MIN_PYTHON_VERSION:
     sys.stderr.write(
@@ -18,22 +45,3 @@ if sys.version_info[:3] < MIN_PYTHON_VERSION:
         "Python >= %d.%d.%d is required\n" % MIN_PYTHON_VERSION
     )
     sys.exit(1)
-
-from firecrest.BasicClient import Firecrest
-from firecrest.AsyncClient import AsyncFirecrest
-from firecrest.ExternalStorage import ExternalDownload, ExternalUpload, ExternalStorage
-from firecrest.AsyncExternalStorage import (
-    AsyncExternalDownload,
-    AsyncExternalUpload,
-    AsyncExternalStorage,
-)
-from firecrest.Authorization import ClientCredentialsAuth
-from firecrest.FirecrestException import (
-    ClientsCredentialsException,
-    FirecrestException,
-    UnauthorizedException,
-    HeaderException,
-    UnexpectedStatusException,
-    StorageDownloadException,
-    StorageUploadException,
-)
