@@ -4,6 +4,7 @@
 #  Please, refer to the LICENSE file in the root directory.
 #  SPDX-License-Identifier: BSD-3-Clause
 #
+import json
 import logging
 import re
 import typer
@@ -64,7 +65,7 @@ custom_theme = {
     "repr.number": "none",
 }
 console = Console(theme=Theme(custom_theme))
-client: fc.Firecrest = None  # type: ignore
+client: fc.v1.Firecrest = None  # type: ignore
 logger = logging.getLogger(__name__)
 
 
@@ -121,7 +122,8 @@ def config_callback(ctx: typer.Context, param: typer.CallbackParam, value: str):
 def services(
     name: Optional[str] = typer.Option(
         None, "-n", "--name", help="Get information for only one service."
-    )
+    ),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
 ):
     """Provides information for the services of FirecREST"""
     try:
@@ -132,6 +134,10 @@ def services(
             result = client.all_services()
             title = "Status of FirecREST services"
 
+        if raw:
+            console.print(json.dumps(result, indent=4))
+            return
+
         table = create_table(
             title,
             result,
@@ -149,7 +155,8 @@ def services(
 def systems(
     name: Optional[str] = typer.Option(
         None, "-n", "--name", help="Get information for only one system."
-    )
+    ),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
 ):
     """Provides information for the available systems in FirecREST"""
     try:
@@ -160,6 +167,10 @@ def systems(
             result = client.all_systems()
             title = "Status of FirecREST systems"
 
+        if raw:
+            console.print(json.dumps(result, indent=4))
+            return
+
         table = create_table(
             title,
             result,
@@ -174,10 +185,16 @@ def systems(
 
 
 @app.command(rich_help_panel="Status commands")
-def parameters():
+def parameters(
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
+):
     """Configurable parameters of FirecREST"""
     try:
         result = client.parameters()
+        if raw:
+            console.print(json.dumps(result, indent=4))
+            return
+
         info = [
             ("Name", "name"),
             ("Value", "value"),
@@ -201,7 +218,75 @@ def parameters():
             *info
         )
 
-        console.print(storage_table, utilities_table, overflow="fold")
+        extra_tables = []
+
+        if "compute" in result:
+            info = [
+                ("Name", "name"),
+                ("Value", "value"),
+                ("Unit", "unit"),
+            ]
+            if "description" in result["compute"][0]:
+                info.append(("Description", "description"))
+
+            compute_table = create_table(
+                "Compute parameters",
+                result["compute"],
+                *info
+            )
+            extra_tables.append(compute_table)
+
+        if "general" in result:
+            info = [
+                ("Name", "name"),
+                ("Value", "value"),
+                ("Unit", "unit"),
+            ]
+            if "description" in result["general"][0]:
+                info.append(("Description", "description"))
+
+            general_table = create_table(
+                "General parameters",
+                result["general"],
+                *info
+            )
+            extra_tables.append(general_table)
+
+        console.print(storage_table, utilities_table, *extra_tables, overflow="fold")
+    except Exception as e:
+        examine_exeption(e)
+        raise typer.Exit(code=1)
+
+
+@app.command(rich_help_panel="Status commands")
+def filesystems(
+    system: Optional[str] = typer.Option(
+        None,
+        "-s",
+        "--system",
+        help="The name of the system where the filesystems belongs to.",
+        envvar="FIRECREST_SYSTEM",
+    ),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
+):
+    """Information about the filesystems that are available through FirecREST"""
+    try:
+        result = client.filesystems(system)
+        if raw:
+            console.print(json.dumps(result, indent=4))
+            return
+
+        for system in result.keys():
+            table = create_table(
+                f"Status of filesystems for `{system}`",
+                result[system],
+                ("Name", "name"),
+                ("Path", "path"),
+                ("Status code", "status_code"),
+                ("Status", "status"),
+                ("Description", "description"),
+            )
+            console.print(table, overflow="fold")
     except Exception as e:
         examine_exeption(e)
         raise typer.Exit(code=1)
@@ -215,10 +300,15 @@ def tasks(
     pager: Optional[bool] = typer.Option(
         True, help="Display the output in a pager application."
     ),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
 ):
     """Retrieve information about the FirecREST tasks of the users"""
     try:
         result = client._tasks(taskids)
+        if raw:
+            console.print(json.dumps(result, indent=4))
+            return
+
         num_results = len(result.values())
         table = create_table(
             f"Task information: {num_results} result{'s' if num_results > 1 else ''}",
@@ -245,7 +335,8 @@ def tasks(
 
 @app.command(rich_help_panel="Utilities commands")
 def ls(
-    config_from_parent: str = typer.Option(None,
+    config_from_parent: str = typer.Option(
+        None,
         callback=config_parent_load_callback,
         is_eager=True,
         hidden=True
@@ -264,13 +355,19 @@ def ls(
         "--show-hidden",
         help="Include directory entries whose names begin with a dot (‘.’).",
     ),
-    raw: bool = typer.Option(False, "--raw", help="Print unformatted."),
+    recursive: bool = typer.Option(
+        False,
+        "-R",
+        "--recursive",
+        help="Recursively list directories encountered.",
+    ),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
 ):
     """List directory contents"""
     try:
-        result = client.list_files(system, path, show_hidden)
+        result = client.list_files(system, path, show_hidden, recursive)
         if raw:
-            console.print(result)
+            console.print(json.dumps(result, indent=4))
         else:
             table = create_table(
                 f"Files in system `{system}` and path `{path}`",
@@ -424,6 +521,62 @@ def cp(
         raise typer.Exit(code=1)
 
 
+@app.command(rich_help_panel="Utilities commands")
+def compress(
+    config_from_parent: str = typer.Option(None,
+        callback=config_parent_load_callback,
+        is_eager=True,
+        hidden=True
+    ),
+    system: str = typer.Option(
+        ...,
+        "-s",
+        "--system",
+        help="The name of the system where the filesystem belongs to.",
+        envvar="FIRECREST_SYSTEM",
+    ),
+    source: str = typer.Argument(..., help="The absolute source path."),
+    destination: str = typer.Argument(..., help="The absolute destination path."),
+):
+    """Compress files using gzip compression.
+    You can name the output file as you like, but typically these files have a .tar.gz extension.
+    """
+    try:
+        client.compress(system, source, destination, fail_on_timeout=False)
+    except Exception as e:
+        examine_exeption(e)
+        raise typer.Exit(code=1)
+
+
+@app.command(rich_help_panel="Utilities commands")
+def extract(
+    config_from_parent: str = typer.Option(None,
+        callback=config_parent_load_callback,
+        is_eager=True,
+        hidden=True
+    ),
+    system: str = typer.Option(
+        ...,
+        "-s",
+        "--system",
+        help="The name of the system where the filesystem belongs to.",
+        envvar="FIRECREST_SYSTEM",
+    ),
+    source: str = typer.Argument(..., help="The absolute source path."),
+    destination: str = typer.Argument(..., help="The absolute destination path."),
+    extension: str = typer.Argument("auto", help="Extension of file. Possible values are `auto`, `.zip`, `.tar`, `.tgz`, `.gz` and `.bz2`."),
+):
+    """Extract files.
+    If you don't select the extension, FirecREST will try to guess the right command based on the extension of the sourcePath.
+    Supported extensions are `.zip`, `.tar`, `.tgz`, `.gz` and `.bz2`.
+    """
+    try:
+        client.extract(system, source, destination, extension, fail_on_timeout=False)
+    except Exception as e:
+        examine_exeption(e)
+        raise typer.Exit(code=1)
+
+
 @app.command(rich_help_panel="Utilities commands")
 def file(
     config_from_parent: str = typer.Option(None,
@@ -464,13 +617,13 @@ def stat(
     ),
     path: str = typer.Argument(..., help="The absolute target path."),
     deref: bool = typer.Option(False, "-L", "--dereference", help="Follow links."),
-    raw: bool = typer.Option(False, "--raw", help="Print unformatted."),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
 ):
     """Use the stat linux application to determine the status of a file on the system's filesystem"""
     try:
         result = client.stat(system, path, deref)
         if raw:
-            console.print(result)
+            console.print(json.dumps(result, indent=4))
         else:
             title = f"Status of file {path}"
             if deref:
@@ -769,6 +922,34 @@ def whoami(
         raise typer.Exit(code=1)
 
 
+@app.command(rich_help_panel="Utilities commands")
+def id(
+    config_from_parent: str = typer.Option(None,
+        callback=config_parent_load_callback,
+        is_eager=True,
+        hidden=True
+    ),
+    system: str = typer.Option(
+        None,
+        "-s",
+        "--system",
+        help="The name of the system where the `id` command will run.",
+        envvar="FIRECREST_SYSTEM",
+    ),
+):
+    """Return the identity of the user in the remote system.
+    """
+    try:
+        result = client.groups(system)
+        user = f"{result['user']['id']}({result['user']['name']})"
+        group = f"{result['group']['id']}({result['group']['name']})"
+        all_groups = ",".join([f"{g['id']}({g['name']})" for g in result["groups"]])
+        console.print(f"uid={user} gid={group} groups={all_groups}")
+    except Exception as e:
+        examine_exeption(e)
+        raise typer.Exit(code=1)
+
+
 class TransferType(str, Enum):
     direct = "direct"
     external = "external"
@@ -797,7 +978,7 @@ def download(
         TransferType.direct,
         "--type",
         case_sensitive=False,
-        help=f"Select type of transfer.",
+        help="Select type of transfer.",
     ),
 ):
     """Download a file
@@ -856,7 +1037,7 @@ def upload(
         TransferType.direct,
         "--type",
         case_sensitive=False,
-        help=f"Select type of transfer.",
+        help="Select type of transfer.",
     ),
 ):
     """Upload a file
@@ -885,13 +1066,13 @@ def upload(
                     console.print(
                         "\nNecessary information to upload the file in the staging area:"
                     )
-                    console.print(f"[yellow]{data['parameters']}[/yellow]")
+                    console.print(f"[yellow]{json.dumps(data['parameters'], indent=4)}[/yellow]")
                     console.print(
                         "\nOr simply run the following command to finish the upload:"
                     )
                     console.print(f"[green]{data['command']}[/green]")
                 else:
-                    console.print(data)
+                    console.print(json.dumps(data, indent=4))
     except Exception as e:
         examine_exeption(e)
         raise typer.Exit(code=1)
@@ -901,7 +1082,7 @@ def validate_env_var_format(value: List[str]):
     pattern = re.compile(r'\S+=\S+')
     for item in value:
         if not pattern.match(item):
-            raise typer.BadParameter(f"Please use the format `VAR=VALUE`.")
+            raise typer.BadParameter("Please use the format `VAR=VALUE`.")
 
     return value
 
@@ -944,9 +1125,21 @@ def submit(
 
     try:
         if local:
-            console.print(client.submit(system, script_local_path=job_script, account=account, env_vars=envvars))
+            result = client.submit(
+                system,
+                script_local_path=job_script,
+                account=account,
+                env_vars=envvars
+            )
         else:
-            console.print(client.submit(system, script_remote_path=job_script, account=account, env_vars=envvars))
+            result = client.submit(
+                system,
+                script_remote_path=job_script,
+                account=account,
+                env_vars=envvars
+            )
+
+        console.print(json.dumps(result, indent=4))
     except Exception as e:
         examine_exeption(e)
         raise typer.Exit(code=1)
@@ -990,10 +1183,11 @@ def submit_mv(
 ):
     """Move/rename file"""
     try:
+        result = client.submit_move_job(
+            system, source, destination, job_name, time, jobid, account
+        )
         console.print(
-            client.submit_move_job(
-                system, source, destination, job_name, time, jobid, account
-            )
+            json.dumps(result, indent=4)
         )
     except Exception as e:
         examine_exeption(e)
@@ -1038,10 +1232,11 @@ def submit_cp(
 ):
     """Copy file"""
     try:
+        result = client.submit_copy_job(
+            system, source, destination, job_name, time, jobid, account
+        )
         console.print(
-            client.submit_copy_job(
-                system, source, destination, job_name, time, jobid, account
-            )
+            json.dumps(result, indent=4)
         )
     except Exception as e:
         examine_exeption(e)
@@ -1086,10 +1281,120 @@ def submit_rsync(
 ):
     """Transfer/synchronize files or directories efficiently between filesystems"""
     try:
+        result = client.submit_rsync_job(
+            system, source, destination, job_name, time, jobid, account
+        )
         console.print(
-            client.submit_rsync_job(
-                system, source, destination, job_name, time, jobid, account
-            )
+            json.dumps(result, indent=4)
+        )
+    except Exception as e:
+        examine_exeption(e)
+        raise typer.Exit(code=1)
+
+
+@submit_template_app.command("compress")
+def submit_compress(
+    config_from_parent: str = typer.Option(None,
+        callback=config_parent_load_callback,
+        is_eager=True,
+        hidden=True
+    ),
+    system: str = typer.Option(
+        ...,
+        "-s",
+        "--system",
+        help="The name of the system where the filesystem belongs to.",
+        envvar="FIRECREST_SYSTEM",
+    ),
+    source: str = typer.Argument(..., help="The absolute source path."),
+    destination: str = typer.Argument(..., help="The absolute destination path."),
+    job_name: Optional[str] = typer.Option(None, help="Job name in the script."),
+    time: Optional[str] = typer.Option(
+        None,
+        help="""
+        Limit on the total run time of the job.
+
+        Acceptable time formats 'minutes', 'minutes:seconds', 'hours:minutes:seconds', 'days-hours', 'days-hours:minutes' and 'days-hours:minutes:seconds'.
+        """,
+    ),
+    jobid: Optional[str] = typer.Option(
+        None, help="Transfer data after job with ID JOBID is completed."
+    ),
+    account: Optional[str] = typer.Option(
+        None,
+        help="""
+        Name of the project account to be used in SLURM script.
+        If not set, system default is taken.
+        """,
+    ),
+):
+    """Compress files using gzip compression.
+    You can name the output file as you like, but typically these files have a .tar.gz extension."""
+    try:
+        result = client.submit_compress_job(
+            machine=system,
+            source_path=source,
+            target_path=destination,
+            job_name=job_name,
+            time=time,
+            stage_out_job_id=jobid,
+            account=account
+        )
+        console.print(
+            json.dumps(result, indent=4)
+        )
+    except Exception as e:
+        examine_exeption(e)
+        raise typer.Exit(code=1)
+
+
+@submit_template_app.command("extract")
+def submit_extract(
+    config_from_parent: str = typer.Option(None,
+        callback=config_parent_load_callback,
+        is_eager=True,
+        hidden=True
+    ),
+    system: str = typer.Option(
+        ...,
+        "-s",
+        "--system",
+        help="The name of the system where the filesystem belongs to.",
+        envvar="FIRECREST_SYSTEM",
+    ),
+    source: str = typer.Argument(..., help="The absolute source path."),
+    destination: str = typer.Argument(..., help="The absolute destination path."),
+    extension: str = typer.Argument("auto", help="File extension, possible values are `auto`, `.zip`, `.tar`, `.tgz`, `.gz` and `.bz2`."),
+    job_name: Optional[str] = typer.Option(None, help="Job name in the script."),
+    time: Optional[str] = typer.Option(
+        None,
+        help="""
+        Limit on the total run time of the job.
+
+        Acceptable time formats 'minutes', 'minutes:seconds', 'hours:minutes:seconds', 'days-hours', 'days-hours:minutes' and 'days-hours:minutes:seconds'.
+        """,
+    ),
+    jobid: Optional[str] = typer.Option(
+        None, help="Transfer data after job with ID JOBID is completed."
+    ),
+    account: Optional[str] = typer.Option(
+        None,
+        help="""
+        Name of the project account to be used in SLURM script.
+        If not set, system default is taken.
+        """,
+    ),
+):
+    """Extract files.
+    If you don't select the extension, FirecREST will try to guess the right command based on the extension of the sourcePath.
+    Supported extensions are `.zip`, `.tar`, `.tgz`, `.gz` and `.bz2`.
+    """
+    try:
+        result = client.submit_extract_job(
+            system, source, destination, job_name, time, jobid, account
+        )
+        console.print(
+            json.dumps(result, indent=4)
         )
     except Exception as e:
         examine_exeption(e)
@@ -1133,8 +1438,9 @@ def submit_rm(
 ):
     """Remove files"""
     try:
+        result = client.submit_delete_job(system, path, job_name, time, jobid, account)
         console.print(
-            client.submit_delete_job(system, path, job_name, time, jobid, account)
+            json.dumps(result, indent=4)
         )
     except Exception as e:
         examine_exeption(e)
@@ -1162,7 +1468,7 @@ def poll(
         None,
         help="End time (and/or date) of job's query. Allowed formats are `HH:MM\[:SS] \[AM|PM]` or `MMDD\[YY]` or `MM/DD\[/YY]` or `MM.DD\[.YY]` or `MM/DD\[/YY]-HH:MM\[:SS]` or `YYYY-MM-DD\[THH:MM\[:SS]]`.",
     ),
-    raw: bool = typer.Option(False, "--raw", help="Print unformatted."),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
 ):
     """Retrieve information about submitted jobs.
     This call uses the `sacct` command
@@ -1170,7 +1476,7 @@ def poll(
     try:
         result = client.poll(system, jobs, start_time, end_time)
         if raw:
-            console.print(result)
+            console.print(json.dumps(result, indent=4))
         else:
             table = create_table(
                 "Accounting data for jobs",
@@ -1205,7 +1511,7 @@ def poll_active(
     jobs: Optional[List[str]] = typer.Argument(
         None, help="List of job IDs to display."
     ),
-    raw: bool = typer.Option(False, "--raw", help="Print unformatted."),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
 ):
     """Retrieves information about active jobs.
     This call uses the `squeue -u <username>` command
@@ -1213,7 +1519,7 @@ def poll_active(
     try:
         result = client.poll_active(system, jobs)
         if raw:
-            console.print(result)
+            console.print(json.dumps(result, indent=4))
         else:
             table = create_table(
                 "Information about jobs in the queue",
@@ -1235,6 +1541,103 @@ def poll_active(
         raise typer.Exit(code=1)
 
 
+@app.command(rich_help_panel="Compute commands")
+def get_nodes(
+    config_from_parent: str = typer.Option(None,
+        callback=config_parent_load_callback,
+        is_eager=True,
+        hidden=True
+    ),
+    system: str = typer.Option(
+        ..., "-s", "--system", help="The name of the system.", envvar="FIRECREST_SYSTEM"
+    ),
+    nodes: Optional[List[str]] = typer.Argument(
+        None, help="List of specific compute nodes to query."
+    ),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
+):
+    """Retrieves information about the compute nodes.
+    This call uses the `scontrol show nodes` command
+    """
+    try:
+        results = client.nodes(system, nodes)
+        if raw:
+            console.print(json.dumps(results, indent=4))
+        else:
+            parsed_results = []
+            for item in results:
+                parsed_item = {}
+                for key, value in item.items():
+                    if isinstance(value, list):
+                        parsed_item[key] = ", ".join(value)
+                    else:
+                        parsed_item[key] = str(value)
+
+                parsed_results.append(parsed_item)
+
+            table = create_table(
+                "Information about jobs in the queue",
+                parsed_results,
+                ("Name", "NodeName"),
+                ("Partitions", "Partitions"),
+                ("State", "State"),
+                ("Active Features", "ActiveFeatures"),
+            )
+            console.print(table)
+    except Exception as e:
+        examine_exeption(e)
+        raise typer.Exit(code=1)
+
+
+@app.command(rich_help_panel="Compute commands")
+def get_partitions(
+    config_from_parent: str = typer.Option(None,
+        callback=config_parent_load_callback,
+        is_eager=True,
+        hidden=True
+    ),
+    system: str = typer.Option(
+        ..., "-s", "--system", help="The name of the system.", envvar="FIRECREST_SYSTEM"
+    ),
+    partitions: Optional[List[str]] = typer.Argument(
+        None, help="List of specific partitions to query."
+    ),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
+):
+    """Retrieves information about the partitions.
+    This call uses the `scontrol show partitions` command
+    """
+    try:
+        results = client.partitions(system, partitions)
+        if raw:
+            console.print(json.dumps(results, indent=4))
+        else:
+            parsed_results = []
+            for item in results:
+                parsed_item = {}
+                for key, value in item.items():
+                    if isinstance(value, list):
+                        parsed_item[key] = ", ".join(value)
+                    else:
+                        parsed_item[key] = str(value)
+
+                parsed_results.append(parsed_item)
+
+            table = create_table(
+                "Information about partitions in the system",
+                parsed_results,
+                ("Name", "PartitionName"),
+                ("State", "State"),
+                ("Total CPUs", "TotalCPUs"),
+                ("Total Nodes", "TotalNodes"),
+                ("Is default", "Default"),
+            )
+            console.print(table)
+    except Exception as e:
+        examine_exeption(e)
+        raise typer.Exit(code=1)
+
+
 @app.command(rich_help_panel="Compute commands")
 def cancel(
     config_from_parent: str = typer.Option(None,
@@ -1255,8 +1658,8 @@ def cancel(
         raise typer.Exit(code=1)
 
 
-@reservation_app.command(rich_help_panel="Reservation commands")
-def list(
+@app.command(rich_help_panel="Compute commands")
+def get_reservations(
     config_from_parent: str = typer.Option(None,
         callback=config_parent_load_callback,
         is_eager=True,
@@ -1265,101 +1668,41 @@ def list(
     system: str = typer.Option(
         ..., "-s", "--system", help="The name of the system.", envvar="FIRECREST_SYSTEM"
     ),
+    reservations: Optional[List[str]] = typer.Argument(
+        None, help="List of specific reservations to query."
+    ),
+    raw: bool = typer.Option(False, "--json", "--raw", help="Print the output in json format."),
 ):
-    """List all active reservations and their status"""
+    """Retrieves information about the reservations.
+    This call uses the `scontrol show reservations` command
+    """
     try:
-        res = client.all_reservations(system)
-        console.print(res)
-    except Exception as e:
-        examine_exeption(e)
-        raise typer.Exit(code=1)
+        results = client.reservations(system, reservations)
+        if raw:
+            console.print(json.dumps(results, indent=4))
+        else:
+            parsed_results = []
+            for item in results:
+                parsed_item = {}
+                for key, value in item.items():
+                    if isinstance(value, list):
+                        parsed_item[key] = ", ".join(value)
+                    else:
+                        parsed_item[key] = str(value)
 
+                parsed_results.append(parsed_item)
 
-@reservation_app.command(rich_help_panel="Reservation commands")
-def create(
-    config_from_parent: str = typer.Option(None,
-        callback=config_parent_load_callback,
-        is_eager=True,
-        hidden=True
-    ),
-    system: str = typer.Option(
-        ..., "-s", "--system", help="The name of the system.", envvar="FIRECREST_SYSTEM"
-    ),
-    name: str = typer.Argument(..., help="The reservation name."),
-    account: str = typer.Argument(
-        ..., help="The account in SLURM to which the reservation is made for."
-    ),
-    num_nodes: str = typer.Argument(
-        ..., help="The number of nodes needed for the reservation."
-    ),
-    node_type: str = typer.Argument(..., help="The node type."),
-    start_time: str = typer.Argument(
-        ..., help="The start time for reservation (YYYY-MM-DDTHH:MM:SS)."
-    ),
-    end_time: str = typer.Argument(
-        ..., help="The end time for reservation (YYYY-MM-DDTHH:MM:SS)."
-    ),
-):
-    """Create a reservation"""
-    try:
-        client.create_reservation(
-            system, name, account, num_nodes, node_type, start_time, end_time
-        )
-    except Exception as e:
-        examine_exeption(e)
-        raise typer.Exit(code=1)
-
-
-@reservation_app.command(rich_help_panel="Reservation commands")
-def update(
-    config_from_parent: str = typer.Option(None,
-        callback=config_parent_load_callback,
-        is_eager=True,
-        hidden=True
-    ),
-    system: str = typer.Option(
-        ..., "-s", "--system", help="The name of the system.", envvar="FIRECREST_SYSTEM"
-    ),
-    name: str = typer.Argument(..., help="The reservation name."),
-    account: str = typer.Argument(
-        ..., help="The account in SLURM to which the reservation is made for."
-    ),
-    num_nodes: str = typer.Argument(
-        ..., help="The number of nodes needed for the reservation."
-    ),
-    node_type: str = typer.Argument(..., help="The node type."),
-    start_time: str = typer.Argument(
-        ..., help="The start time for reservation (YYYY-MM-DDTHH:MM:SS)."
-    ),
-    end_time: str = typer.Argument(
-        ..., help="The end time for reservation (YYYY-MM-DDTHH:MM:SS)."
-    ),
-):
-    """Update a reservation"""
-    try:
-        client.update_reservation(
-            system, name, account, num_nodes, node_type, start_time, end_time
-        )
-    except Exception as e:
-        examine_exeption(e)
-        raise typer.Exit(code=1)
-
-
-@reservation_app.command(rich_help_panel="Reservation commands")
-def delete(
-    config_from_parent: str = typer.Option(None,
-        callback=config_parent_load_callback,
-        is_eager=True,
-        hidden=True
-    ),
-    system: str = typer.Option(
-        ..., "-s", "--system", help="The name of the system.", envvar="FIRECREST_SYSTEM"
-    ),
-    name: str = typer.Argument(..., help="The reservation name."),
-):
-    """Delete a reservation"""
-    try:
-        client.delete_reservation(system, name)
+            table = create_table(
+                "Information about reservations in the system",
+                parsed_results,
+                ("Name", "ReservationName"),
+                ("State", "State"),
+                ("Nodes", "Nodes"),
+                ("StartTime", "StartTime"),
+                ("EndTime", "EndTime"),
+                ("Features", "Features"),
+            )
+            console.print(table)
     except Exception as e:
         examine_exeption(e)
         raise typer.Exit(code=1)
@@ -1425,7 +1768,7 @@ def main(
     global client
     auth_obj = fc.ClientCredentialsAuth(client_id, client_secret, token_url)
     auth_obj.timeout = auth_timeout
-    client = fc.Firecrest(firecrest_url=firecrest_url, authorization=auth_obj)
+    client = fc.v1.Firecrest(firecrest_url=firecrest_url, authorization=auth_obj)
     client.timeout = timeout
     if api_version:
         client.set_api_version(api_version)
