@@ -9,10 +9,11 @@ import os
 from pathlib import PurePosixPath
 import stat
 import tempfile
-from typing import Callable, Iterator
+from typing import Callable, Iterator, List
 
-from firecrest import Firecrest, ClientCredentialsAuth
-from firecrest.BasicClient import logger as FcLogger
+from firecrest import ClientCredentialsAuth
+from firecrest.v1 import Firecrest
+from firecrest.v1.BasicClient import logger as FcLogger
 from firecrest.FirecrestException import HeaderException
 
 
@@ -311,6 +312,18 @@ class FcPath(os.PathLike):
                 return item._cache.lst_mode
         raise FileNotFoundError(self)
 
+    def resolve(self) -> Self:
+        """Resolve a path, removing '..' and '.' components."""
+        parts: List[str] = []
+        for part in self.parts:
+            if part == '..':
+                if parts:
+                    parts.pop()
+            elif part != '.':
+                parts.append(part)
+
+        return self._new_path(PurePosixPath(*parts))
+
     def _stat_mode(self) -> int:
         """Return the st_mode of the path, following symlinks."""
         if self._cache_enabled and self._cache.st_mode is not None:
@@ -337,7 +350,11 @@ class FcPath(os.PathLike):
                 if stat.S_ISLNK(mode):
                     if not item._cache.link_target:
                         raise FileNotFoundError(f"Symlink has no target path: {self}")
-                    path = self._new_path(PurePosixPath(item._cache.link_target))
+                    pureposixpath = PurePosixPath(item._cache.link_target)
+                    if not pureposixpath.is_absolute():
+                        path = path.parent.joinpath(pureposixpath).resolve()
+                    else:
+                        path = self._new_path(pureposixpath)
                     followed_links += 1
                     break
                 else:
@@ -455,11 +472,11 @@ class FcPath(os.PathLike):
             return False
         return stat.S_ISSOCK(st_mode)
 
-    def iterdir(self, hidden=True) -> Iterator[Self]:
+    def iterdir(self, hidden=True, recursive=False) -> Iterator[Self]:
         """Iterate over the directory entries."""
         with self.convert_header_exceptions():
             results = self._client.list_files(
-                self._machine, self.path, show_hidden=hidden
+                self._machine, self.path, show_hidden=hidden, recursive=recursive
             )
         for entry in results:
             yield self._new_path(
@@ -470,6 +487,10 @@ class FcPath(os.PathLike):
                 ),
             )
 
+    def relpath(self, start: str | PurePosixPath) -> str:
+        """Return a relative version of this path."""
+        return self._path.relative_to(start).as_posix()
+
     # operations that modify a file
 
     def chmod(self, mode: int) -> None:
@@ -513,16 +534,11 @@ class FcPath(os.PathLike):
         """Create a new directory at this given path."""
         if mode is not None:
             raise NotImplementedError("mode is not supported yet")
-        try:
-            with self.convert_header_exceptions(
-                {
-                    "X-A-Directory": FileExistsError  # Note see: https://github.com/eth-cscs/firecrest/issues/172
-                }
-            ):
-                self._client.mkdir(self._machine, self.path, p=parents)
-        except FileExistsError:
-            if not exist_ok:
-                raise
+        with self.convert_header_exceptions():
+            # Note see: https://github.com/eth-cscs/firecrest/issues/172
+            # Also see: https://github.com/eth-cscs/firecrest/issues/202
+            # firecrest does not support `exist_ok`, it's somehow blended into `parents`
+            self._client.mkdir(self._machine, self.path, p=parents if not exist_ok else True)
 
     def touch(self, mode: None = None, exist_ok: bool = True) -> None:
         """Create a file at this given path.
