@@ -23,10 +23,14 @@ class Parameter(TypedDict):
 
 
 class Parameters(TypedDict):
-    """A parameters record, from `status/parameters`"""
+    """A parameters record, from `status/parameters`. For older versions
+    of the API `compute` and `system` may not be present.
+    """
 
     storage: list[Parameter]
     utilities: list[Parameter]
+    compute: list[Parameter]
+    general: list[Parameter]
 
 
 class Service(TypedDict):
@@ -46,6 +50,16 @@ class System(TypedDict):
     system: str
 
 
+class Filesystem(TypedDict):
+    """A filesystem record, from `status/filesystems`"""
+
+    name: str
+    path: str
+    description: str
+    status: int
+    status_code: str
+
+
 class Task(TypedDict):
     """A task record, from `/tasks`"""
 
@@ -56,6 +70,7 @@ class Task(TypedDict):
     last_modify: str
     service: str
     status: str
+    system: str
     task_id: str
     updated_at: str
     user: str
@@ -129,6 +144,36 @@ class JobQueue(TypedDict):
     user: str
 
 
+class NodeInfo(TypedDict):
+    """A node record record, from `compute/nodes`"""
+
+    NodeName: str
+    ActiveFeatures: list[str]
+    Partitions: list[str]
+    State: list[str]
+
+
+class PartitionInfo(TypedDict):
+    """A node record record, from `compute/partitions`"""
+
+    Default: str
+    PartitionName: str
+    State: str
+    TotalCPUs: str
+    TotalNodes: str
+
+
+class ReservationInfo(TypedDict):
+    """A job queue record, from `compute/reservations`"""
+
+    ReservationName: str
+    State: str
+    Nodes: str
+    StartTime: str
+    EndTime: str
+    Features: str
+
+
 class JobSubmit(TypedDict):
     """A job submit record, from `compute/jobs`"""
 
@@ -140,3 +185,22 @@ class JobSubmit(TypedDict):
     job_file_out: str
     jobid: int
     result: str
+
+
+class InternalTransferJobSubmit(JobSubmit):
+    """A transfer job submit record, from `storage/xfer-internal/{op}`"""
+
+    system: str
+
+
+class Id(TypedDict):
+    name: str
+    id: str
+
+
+class UserId(TypedDict):
+    """A record from the `id` command"""
+
+    user: Id
+    group: Id
+    groups: list[Id]
