@@ -44,7 +44,7 @@ def client1(fc_server):
             # }
             return "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJyZWFsbV9hY2Nlc3MiOnsicm9sZXMiOlsiZmlyZWNyZXN0LXNhIl19LCJyZXNvdXJjZV9hY2Nlc3MiOnsiYm9iLWNsaWVudCI6eyJyb2xlcyI6WyJib2IiXX19LCJjbGllbnRJZCI6ImJvYi1jbGllbnQiLCJwcmVmZXJyZWRfdXNlcm5hbWUiOiJzZXJ2aWNlLWFjY291bnQtYm9iLWNsaWVudCJ9.XfCXDclEBh7faQrOF2piYdnb7c3AUiCxDesTkNSwpSY"
 
-    return firecrest.Firecrest(
+    return firecrest.v1.Firecrest(
         firecrest_url=fc_server.url_for("/"), authorization=ValidAuthorization()
     )
 
@@ -64,7 +64,7 @@ def client2(fc_server):
             # }
             return "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJyZWFsbV9hY2Nlc3MiOnsicm9sZXMiOlsib3RoZXItcm9sZSJdfSwicHJlZmVycmVkX3VzZXJuYW1lIjoiYWxpY2UifQ.dpo1_F9jkV-RpNGqTaCNLbM-JPMnstDg7mQjzbwDp5g"
 
-    return firecrest.Firecrest(
+    return firecrest.v1.Firecrest(
         firecrest_url=fc_server.url_for("/"), authorization=ValidAuthorization()
     )
 
@@ -79,7 +79,7 @@ def client3(fc_server):
             # }
             return "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJwcmVmZXJyZWRfdXNlcm5hbWUiOiJldmUifQ.SGVPDrJdy8b5jRpxcw9ILLsf8M2ljAYWxiN0A1b_1SE"
 
-    return firecrest.Firecrest(
+    return firecrest.v1.Firecrest(
         firecrest_url=fc_server.url_for("/"), authorization=ValidAuthorization()
     )
 
@@ -90,9 +90,11 @@ def valid_client(fc_server):
         def get_access_token(self):
             return "VALID_TOKEN"
 
-    return firecrest.Firecrest(
+    client = firecrest.v1.Firecrest(
         firecrest_url=fc_server.url_for("/"), authorization=ValidAuthorization()
     )
+    client.set_api_version("1.16.0")
+    return client
 
 
 @pytest.fixture
@@ -102,6 +104,7 @@ def valid_credentials(fc_server, auth_server):
         "--client-id=valid_id",
         "--client-secret=valid_secret",
         f"--token-url={auth_server.url_for('/auth/token')}",
+        "--api-version=1.16.0",
     ]
 
 
@@ -111,9 +114,11 @@ def invalid_client(fc_server):
         def get_access_token(self):
             return "INVALID_TOKEN"
 
-    return firecrest.Firecrest(
+    client = firecrest.v1.Firecrest(
         firecrest_url=fc_server.url_for("/"), authorization=InvalidAuthorization()
     )
+    client.set_api_version("1.16.0")
+    return client
 
 
 def tasks_handler(request: Request):
@@ -133,6 +138,7 @@ def tasks_handler(request: Request):
             "last_modify": "2022-08-16T07:18:54",
             "service": "storage",
             "status": "114",
+            "system": "cluster1",
             "task_id": "taskid_1",
             "task_url": "TASK_IP/tasks/taskid_1",
             "updated_at": "2022-08-16T07:18:54",
@@ -146,6 +152,7 @@ def tasks_handler(request: Request):
             "last_modify": "2022-08-16T07:18:54",
             "service": "storage",
             "status": "112",
+            "system": "cluster1",
             "task_id": "taskid_2",
             "task_url": "TASK_IP/tasks/taskid_2",
             "updated_at": "2022-08-16T07:18:54",
@@ -159,6 +166,7 @@ def tasks_handler(request: Request):
             "last_modify": "2022-08-16T07:18:54",
             "service": "storage",
             "status": "111",
+            "system": "cluster1",
             "task_id": "taskid_3",
             "task_url": "TASK_IP/tasks/taskid_3",
             "updated_at": "2022-08-16T07:18:54",
@@ -224,6 +232,7 @@ def test_all_tasks(valid_client):
             "last_modify": "2022-08-16T07:18:54",
             "service": "storage",
             "status": "114",
+            "system": "cluster1",
             "task_id": "taskid_1",
             "task_url": "TASK_IP/tasks/taskid_1",
             "updated_at": "2022-08-16T07:18:54",
@@ -237,6 +246,7 @@ def test_all_tasks(valid_client):
             "last_modify": "2022-08-16T07:18:54",
             "service": "storage",
             "status": "112",
+            "system": "cluster1",
             "task_id": "taskid_2",
             "task_url": "TASK_IP/tasks/taskid_2",
             "updated_at": "2022-08-16T07:18:54",
@@ -250,6 +260,7 @@ def test_all_tasks(valid_client):
             "last_modify": "2022-08-16T07:18:54",
             "service": "storage",
             "status": "111",
+            "system": "cluster1",
             "task_id": "taskid_3",
             "task_url": "TASK_IP/tasks/taskid_3",
             "updated_at": "2022-08-16T07:18:54",
@@ -281,6 +292,7 @@ def test_subset_tasks(valid_client):
             "last_modify": "2022-08-16T07:18:54",
             "service": "storage",
             "status": "114",
+            "system": "cluster1",
             "task_id": "taskid_1",
             "task_url": "TASK_IP/tasks/taskid_1",
             "updated_at": "2022-08-16T07:18:54",
@@ -294,6 +306,7 @@ def test_subset_tasks(valid_client):
             "last_modify": "2022-08-16T07:18:54",
             "service": "storage",
             "status": "111",
+            "system": "cluster1",
             "task_id": "taskid_3",
             "task_url": "TASK_IP/tasks/taskid_3",
             "updated_at": "2022-08-16T07:18:54",
@@ -324,6 +337,7 @@ def test_one_task(valid_client):
             "last_modify": "2022-08-16T07:18:54",
             "service": "storage",
             "status": "112",
+            "system": "cluster1",
             "task_id": "taskid_2",
             "task_url": "TASK_IP/tasks/taskid_2",
             "updated_at": "2022-08-16T07:18:54",
