@@ -21,9 +21,11 @@ def valid_client(fc_server):
         def get_access_token(self):
             return "VALID_TOKEN"
 
-    return firecrest.Firecrest(
+    client = firecrest.v1.Firecrest(
         firecrest_url=fc_server.url_for("/"), authorization=ValidAuthorization()
     )
+    client.set_api_version("1.16.0")
+    return client
 
 
 @pytest.fixture
@@ -33,6 +35,7 @@ def valid_credentials(fc_server, auth_server):
         "--client-id=valid_id",
         "--client-secret=valid_secret",
         f"--token-url={auth_server.url_for('/auth/token')}",
+        "--api-version=1.16.0",
     ]
 
 
@@ -42,9 +45,11 @@ def invalid_client(fc_server):
         def get_access_token(self):
             return "INVALID_TOKEN"
 
-    return firecrest.Firecrest(
+    client = firecrest.v1.Firecrest(
         firecrest_url=fc_server.url_for("/"), authorization=InvalidAuthorization()
     )
+    client.set_api_version("1.16.0")
+    return client
 
 
 def internal_transfer_handler(request: Request):
@@ -210,6 +215,7 @@ def storage_tasks_handler(request: Request):
                         "last_modify": "2021-12-04T11:52:10",
                         "service": "compute",
                         "status": "100",
+                        "system": "cluster1",
                         "task_id": taskid,
                         "task_url": f"TASK_IP/tasks/{taskid}",
                         "user": "username",
@@ -235,6 +241,7 @@ def storage_tasks_handler(request: Request):
                         "last_modify": "2021-12-06T13:48:52",
                         "service": "compute",
                         "status": "200",
+                        "system": "cluster1",
                         "task_id": "6f514b060ca036917f4194964b6e949c",
                         "task_url": f"TASK_IP/tasks/{taskid}",
                         "user": "username",
@@ -254,6 +261,7 @@ def storage_tasks_handler(request: Request):
                         "last_modify": "2021-12-04T11:52:10",
                         "service": "storage",
                         "status": "100",
+                        "system": "cluster1",
                         "task_id": taskid,
                         "task_url": f"TASK_IP/tasks/{taskid}",
                         "user": "username",
@@ -272,6 +280,7 @@ def storage_tasks_handler(request: Request):
                         "last_modify": "2021-12-04T11:52:10",
                         "service": "storage",
                         "status": "116",
+                        "system": "cluster1",
                         "task_id": taskid,
                         "task_url": f"TASK_IP/tasks/{taskid}",
                         "user": "username",
@@ -289,6 +298,7 @@ def storage_tasks_handler(request: Request):
                         "last_modify": "2021-12-04T11:52:10",
                         "service": "storage",
                         "status": "117",
+                        "system": "cluster1",
                         "task_id": taskid,
                         "task_url": f"TASK_IP/tasks/{taskid}",
                         "user": "username",
@@ -310,6 +320,7 @@ def storage_tasks_handler(request: Request):
                         "last_modify": "2021-12-04T11:52:10",
                         "service": "storage",
                         "status": "117",
+                        "system": "cluster1",
                         "task_id": taskid,
                         "task_url": f"TASK_IP/tasks/{taskid}",
                         "user": "username",
@@ -329,6 +340,7 @@ def storage_tasks_handler(request: Request):
                         "last_modify": "2021-12-04T11:52:10",
                         "service": "storage",
                         "status": "100",
+                        "system": "cluster1",
                         "task_id": taskid,
                         "task_url": f"TASK_IP/tasks/{taskid}",
                         "user": "username",
@@ -347,6 +359,7 @@ def storage_tasks_handler(request: Request):
                             "msg": "Waiting for Presigned URL to upload file to staging area (OpenStack Swift)",
                             "source": "/path/to/local/source",
                             "status": "110",
+                            "system": "cluster1",
                             "system_addr": "machine_addr",
                             "system_name": "cluster1",
                             "target": "/path/to/remote/destination",
@@ -358,6 +371,7 @@ def storage_tasks_handler(request: Request):
                         "last_modify": "2022-11-23T09:07:50",
                         "service": "storage",
                         "status": "110",
+                        "system": "cluster1",
                         "task_id": "taskid",
                         "task_url": f"TASK_IP/tasks/{taskid}",
                         "updated_at": "2022-11-23T09:07:50",
@@ -393,6 +407,7 @@ def storage_tasks_handler(request: Request):
                             },
                             "source": "/path/to/local/source",
                             "status": "111",
+                            "system": "cluster1",
                             "system_addr": "machine_addr",
                             "system_name": "cluster1",
                             "target": "/path/to/remote/destination",
@@ -404,6 +419,7 @@ def storage_tasks_handler(request: Request):
                         "last_modify": "2022-11-23T09:18:43",
                         "service": "storage",
                         "status": "111",
+                        "system": "cluster1",
                         "task_id": taskid,
                         "task_url": f"TASK_IP/tasks/{taskid}",
                         "updated_at": "2022-11-23T09:18:43",
@@ -466,6 +482,7 @@ def test_internal_transfer(valid_client):
         "job_file_out": "/path/to/firecrest/internal_transfer_id/job-35363861.out",
         "jobid": 35363861,
         "result": "Job submitted",
+        "system": "cluster1",
     }
 
     # cp job
@@ -486,6 +503,7 @@ def test_internal_transfer(valid_client):
         "job_file_out": "/path/to/firecrest/internal_transfer_id/job-35363861.out",
         "jobid": 35363861,
         "result": "Job submitted",
+        "system": "cluster1",
     }
 
     # rsync job
@@ -506,6 +524,7 @@ def test_internal_transfer(valid_client):
         "job_file_out": "/path/to/firecrest/internal_transfer_id/job-35363861.out",
         "jobid": 35363861,
         "result": "Job submitted",
+        "system": "cluster1",
     }
 
     # rm job
@@ -525,6 +544,7 @@ def test_internal_transfer(valid_client):
         "job_file_out": "/path/to/firecrest/internal_transfer_id/job-35363861.out",
         "jobid": 35363861,
         "result": "Job submitted",
+        "system": "cluster1",
     }
 
 
@@ -631,7 +651,7 @@ def test_external_download(valid_client):
     external_download_retry = 0
     valid_client.set_api_version("1.14.0")
     obj = valid_client.external_download("cluster1", "/path/to/remote/source")
-    assert isinstance(obj, firecrest.ExternalDownload)
+    assert isinstance(obj, firecrest.v1.ExternalDownload)
     assert obj._task_id == "external_download_id"
     assert obj.client == valid_client
 
@@ -641,7 +661,7 @@ def test_external_download_legacy(valid_client):
     external_download_retry = 0
     valid_client.set_api_version("1.13.0")
     obj = valid_client.external_download("cluster1", "/path/to/remote/sourcelegacy")
-    assert isinstance(obj, firecrest.ExternalDownload)
+    assert isinstance(obj, firecrest.v1.ExternalDownload)
     assert obj._task_id == "external_download_id_legacy"
     assert obj.client == valid_client
 
@@ -696,7 +716,7 @@ def test_external_upload(valid_client):
     obj = valid_client.external_upload(
         "cluster1", "/path/to/local/source", "/path/to/remote/destination"
     )
-    assert isinstance(obj, firecrest.ExternalUpload)
+    assert isinstance(obj, firecrest.v1.ExternalUpload)
     assert obj._task_id == "external_upload_id"
     assert obj.client == valid_client
 
