@@ -20,9 +20,11 @@ def valid_client(fc_server):
         def get_access_token(self):
             return "VALID_TOKEN"
 
-    return firecrest.Firecrest(
+    client = firecrest.v1.Firecrest(
         firecrest_url=fc_server.url_for("/"), authorization=ValidAuthorization()
     )
+    client.set_api_version("1.16.0")
+    return client
 
 
 @pytest.fixture
@@ -32,6 +34,7 @@ def valid_credentials(fc_server, auth_server):
         "--client-id=valid_id",
         "--client-secret=valid_secret",
         f"--token-url={auth_server.url_for('/auth/token')}",
+        "--api-version=1.16.0",
     ]
 
 
@@ -41,9 +44,11 @@ def invalid_client(fc_server):
         def get_access_token(self):
             return "INVALID_TOKEN"
 
-    return firecrest.Firecrest(
+    client = firecrest.v1.Firecrest(
         firecrest_url=fc_server.url_for("/"), authorization=InvalidAuthorization()
     )
+    client.set_api_version("1.16.0")
+    return client
 
 
 def ls_handler(request: Request):
@@ -333,6 +338,86 @@ def copy_handler(request: Request):
     )
 
 
+def compress_handler(request: Request):
+    if request.headers["Authorization"] != "Bearer VALID_TOKEN":
+        return Response(
+            json.dumps({"message": "Bad token; invalid JSON"}),
+            status=401,
+            content_type="application/json",
+        )
+
+    if request.headers["X-Machine-Name"] != "cluster1":
+        return Response(
+            json.dumps(
+                {"description": "Error on compress operation", "error": "Machine does not exist"}
+            ),
+            status=400,
+            headers={"X-Machine-Does-Not-Exist": "Machine does not exist"},
+            content_type="application/json",
+        )
+
+    extra_headers = None
+    source_path = request.form["sourcePath"]
+    target_path = request.form["targetPath"]
+    if (
+        source_path == "/path/to/valid/source"
+        and target_path == "/path/to/valid/destination.tar.gz"
+    ):
+        ret = {"description": "Success to compress file or directory.", "output": ""}
+        status_code = 201
+    else:
+        extra_headers = {"X-Invalid-Path": "path is an invalid path"}
+        ret = {"description": "Error on compress operation"}
+        status_code = 400
+
+    return Response(
+        json.dumps(ret),
+        status=status_code,
+        headers=extra_headers,
+        content_type="application/json",
+    )
+
+
+def extract_handler(request: Request):
+    if request.headers["Authorization"] != "Bearer VALID_TOKEN":
+        return Response(
+            json.dumps({"message": "Bad token; invalid JSON"}),
+            status=401,
+            content_type="application/json",
+        )
+
+    if request.headers["X-Machine-Name"] != "cluster1":
+        return Response(
+            json.dumps(
+                {"description": "Error on compress operation", "error": "Machine does not exist"}
+            ),
+            status=400,
+            headers={"X-Machine-Does-Not-Exist": "Machine does not exist"},
+            content_type="application/json",
+        )
+
+    extra_headers = None
+    source_path = request.form["sourcePath"]
+    target_path = request.form["targetPath"]
+    if (
+        source_path == "/path/to/valid/source.tar.gz"
+        and target_path == "/path/to/valid/destination"
+    ):
+        ret = {"description": "Success to extract file or directory.", "output": ""}
+        status_code = 201
+    else:
+        extra_headers = {"X-Invalid-Path": "path is an invalid path"}
+        ret = {"description": "Error on extract operation"}
+        status_code = 400
+
+    return Response(
+        json.dumps(ret),
+        status=status_code,
+        headers=extra_headers,
+        content_type="application/json",
+    )
+
+
 def file_type_handler(request: Request):
     if request.headers["Authorization"] != "Bearer VALID_TOKEN":
         return Response(
@@ -730,8 +815,21 @@ def whoami_handler(request: Request):
             content_type="application/json",
         )
 
+    groups = request.args.get("groups", False)
+    if groups:
+        ret = {
+            "description": "User information",
+            "output": {
+                "group": {"id": "1000", "name": "group1"},
+                "groups": [{"id": "1000", "name": "group1"}, {"id": "1001", "name": "group2"}],
+                "user": {"id": "10000", "name": "test_user"},
+            }
+        }
+    else:
+        ret = {"description": "Success on whoami operation.", "output": "username"}
+
     return Response(
-        json.dumps({"description": "Success on whoami operation.", "output": "username"}),
+        json.dumps(ret),
         status=200,
         content_type="application/json",
     )
@@ -763,6 +861,14 @@ def fc_server(httpserver):
         copy_handler
     )
 
+    httpserver.expect_request("/utilities/compress", method="POST").respond_with_handler(
+        compress_handler
+    )
+
+    httpserver.expect_request("/utilities/extract", method="POST").respond_with_handler(
+        extract_handler
+    )
+
     httpserver.expect_request("/utilities/file", method="GET").respond_with_handler(
         file_type_handler
     )
@@ -1100,6 +1206,72 @@ def test_copy_invalid_client(invalid_client):
         invalid_client.copy("cluster1", "/path/to/source", "/path/to/destination")
 
 
+def test_compress(valid_client):
+    # Mostly sure this doesn't raise an error
+    assert (
+        valid_client.compress(
+            "cluster1",
+            "/path/to/valid/source",
+            "/path/to/valid/destination.tar.gz"
+        ) == "/path/to/valid/destination.tar.gz"
+    )
+
+
+def test_compress_not_impl(valid_client):
+    valid_client.set_api_version("1.15.0")
+    with pytest.raises(firecrest.NotImplementedOnAPIversion):
+        valid_client.compress(
+            "cluster1",
+            "/path/to/valid/source",
+            "/path/to/valid/destination.tar.gz"
+        )
+
+
+def test_cli_compress(valid_credentials):
+    args = valid_credentials + [
+        "compress",
+        "--system",
+        "cluster1",
+        "/path/to/valid/source",
+        "/path/to/valid/destination.tar.gz",
+    ]
+    result = runner.invoke(cli.app, args=args)
+    assert result.exit_code == 0
+
+
+def test_extract(valid_client):
+    # Mostly sure this doesn't raise an error
+    assert (
+        valid_client.extract(
+            "cluster1",
+            "/path/to/valid/source.tar.gz",
+            "/path/to/valid/destination"
+        ) == "/path/to/valid/destination"
+    )
+
+
+def test_extract_not_impl(valid_client):
+    valid_client.set_api_version("1.15.0")
+    with pytest.raises(firecrest.NotImplementedOnAPIversion):
+        valid_client.extract(
+            "cluster1",
+            "/path/to/valid/source.tar.gz",
+            "/path/to/valid/destination"
+        )
+
+
+def test_cli_extract(valid_credentials):
+    args = valid_credentials + [
+        "extract",
+        "--system",
+        "cluster1",
+        "/path/to/valid/source.tar.gz",
+        "/path/to/valid/destination",
+    ]
+    result = runner.invoke(cli.app, args=args)
+    assert result.exit_code == 0
+
+
 def test_file_type(valid_client):
     assert valid_client.file_type("cluster1", "/path/to/empty/file") == "empty"
     assert valid_client.file_type("cluster1", "/path/to/directory") == "directory"
@@ -1510,3 +1682,43 @@ def test_whoami_invalid_machine(valid_client):
 def test_whoami_invalid_client(invalid_client):
     with pytest.raises(firecrest.UnauthorizedException):
         invalid_client.whoami("cluster1")
+
+
+def test_cli_whoami(valid_credentials):
+    args = valid_credentials + ["whoami", "--system", "cluster1"]
+    result = runner.invoke(cli.app, args=args)
+    stdout = common.clean_stdout(result.stdout)
+    assert result.exit_code == 0
+    assert "username" in stdout
+
+
+def test_groups(valid_client):
+    assert valid_client.groups("cluster1") == {
+        "group": {"id": "1000", "name": "group1"},
+        "groups": [{"id": "1000", "name": "group1"}, {"id": "1001", "name": "group2"}],
+        "user": {"id": "10000", "name": "test_user"},
+    }
+
+
+def test_groups_not_impl(valid_client):
+    valid_client.set_api_version("1.14.0")
+    with pytest.raises(firecrest.NotImplementedOnAPIversion):
+        valid_client.groups(machine="cluster1")
+
+
+def test_groups_invalid_machine(valid_client):
+    with pytest.raises(firecrest.HeaderException):
+        valid_client.groups("cluster2")
+
+
+def test_groups_invalid_client(invalid_client):
+    with pytest.raises(firecrest.UnauthorizedException):
+        invalid_client.groups("cluster1")
+
+
+def test_cli_id(valid_credentials):
+    args = valid_credentials + ["id", "--system", "cluster1"]
+    result = runner.invoke(cli.app, args=args)
+    stdout = common.clean_stdout(result.stdout)
+    assert result.exit_code == 0
+    assert "uid=10000(test_user) gid=1000(group1) groups=1000(group1),1001(group2)" in stdout
