@@ -12,7 +12,7 @@ def valid_client(fc_server):
         def get_access_token(self):
             return "VALID_TOKEN"
 
-    client = firecrest.AsyncFirecrest(
+    client = firecrest.v1.AsyncFirecrest(
         firecrest_url=fc_server.url_for("/"), authorization=ValidAuthorization()
     )
     client.time_between_calls = {
@@ -23,6 +23,7 @@ def valid_client(fc_server):
         "tasks": 0,
         "utilities": 0,
     }
+    client.set_api_version("1.16.0")
 
     return client
 
@@ -33,7 +34,7 @@ def invalid_client(fc_server):
         def get_access_token(self):
             return "INVALID_TOKEN"
 
-    client = firecrest.AsyncFirecrest(
+    client = firecrest.v1.AsyncFirecrest(
         firecrest_url=fc_server.url_for("/"), authorization=InvalidAuthorization()
     )
     client.time_between_calls = {
@@ -44,6 +45,7 @@ def invalid_client(fc_server):
         "tasks": 0,
         "utilities": 0,
     }
+    client.set_api_version("1.16.0")
 
     return client
 
@@ -74,6 +76,14 @@ def fc_server(httpserver):
         basic_utilities.copy_handler
     )
 
+    httpserver.expect_request("/utilities/compress", method="POST").respond_with_handler(
+        basic_utilities.compress_handler
+    )
+
+    httpserver.expect_request("/utilities/extract", method="POST").respond_with_handler(
+        basic_utilities.extract_handler
+    )
+
     httpserver.expect_request("/utilities/file", method="GET").respond_with_handler(
         basic_utilities.file_type_handler
     )
@@ -358,6 +368,52 @@ async def test_copy_invalid_client(invalid_client):
         await invalid_client.copy("cluster1", "/path/to/source", "/path/to/destination")
 
 
+@pytest.mark.asyncio
+async def test_compress(valid_client):
+    # Mostly sure this doesn't raise an error
+    assert (
+       await valid_client.compress(
+            "cluster1",
+            "/path/to/valid/source",
+            "/path/to/valid/destination.tar.gz"
+        ) == "/path/to/valid/destination.tar.gz"
+    )
+
+
+@pytest.mark.asyncio
+async def test_compress_not_impl(valid_client):
+    valid_client.set_api_version("1.15.0")
+    with pytest.raises(firecrest.NotImplementedOnAPIversion):
+        await valid_client.compress(
+            "cluster1",
+            "/path/to/valid/source",
+            "/path/to/valid/destination.tar.gz"
+        )
+
+
+@pytest.mark.asyncio
+async def test_extract(valid_client):
+    # Mostly sure this doesn't raise an error
+    assert (
+        await valid_client.extract(
+            "cluster1",
+            "/path/to/valid/source.tar.gz",
+            "/path/to/valid/destination"
+        ) == "/path/to/valid/destination"
+    )
+
+
+@pytest.mark.asyncio
+async def test_extract_not_impl(valid_client):
+    valid_client.set_api_version("1.15.0")
+    with pytest.raises(firecrest.NotImplementedOnAPIversion):
+        await valid_client.extract(
+            "cluster1",
+            "/path/to/valid/source.tar.gz",
+            "/path/to/valid/destination"
+        )
+
+
 @pytest.mark.asyncio
 async def test_file_type(valid_client):
     assert await valid_client.file_type("cluster1", "/path/to/empty/file") == "empty"
@@ -651,3 +707,32 @@ async def test_whoami_invalid_machine(valid_client):
 async def test_whoami_invalid_client(invalid_client):
     with pytest.raises(firecrest.UnauthorizedException):
         await invalid_client.whoami("cluster1")
+
+
+@pytest.mark.asyncio
+async def test_groups(valid_client):
+    assert await valid_client.groups("cluster1") == {
+        "group": {"id": "1000", "name": "group1"},
+        "groups": [{"id": "1000", "name": "group1"}, {"id": "1001", "name": "group2"}],
+        "user": {"id": "10000", "name": "test_user"},
+    }
+
+
+@pytest.mark.asyncio
+async def test_groups_not_impl(valid_client):
+    valid_client.set_api_version("1.14.0")
+    with pytest.raises(firecrest.NotImplementedOnAPIversion):
+        await valid_client.groups(machine="cluster1")
+
+
+@pytest.mark.asyncio
+async def test_groups_invalid_machine(valid_client):
+    with pytest.raises(firecrest.HeaderException):
+        await valid_client.groups("cluster2")
+
+
+@pytest.mark.asyncio
+async def test_groups_invalid_client(invalid_client):
+    with pytest.raises(firecrest.UnauthorizedException):
+        await invalid_client.groups("cluster1")
+
